# [START import_module]
from datetime import timedelta

# The DAG object; we'll need this to instantiate a DAG
from airflow import DAG
# Operators; we need this to operate!
from airflow.operators.bash_operator import BashOperator
from airflow.utils.dates import days_ago

# [END import_module]

# [START default_args]
# These args will get passed on to each operator
# You can override them on a per-task basis during operator initialization
default_args = {
    'owner': 'airflow',
    'depends_on_past': False,
    'start_date': days_ago(2),
    'email': ['myself@theja.org'],
    'email_on_failure': False,
    'email_on_retry': False,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
    # 'queue': 'bash_queue',
    # 'pool': 'backfill',
    # 'priority_weight': 10,
    # 'end_date': datetime(2016, 1, 1),
    # 'wait_for_downstream': False,
    # 'dag': dag,
    # 'sla': timedelta(hours=2),
    # 'execution_timeout': timedelta(seconds=300),
    # 'on_failure_callback': some_function,
    # 'on_success_callback': some_other_function,
    # 'on_retry_callback': another_function,
    # 'sla_miss_callback': yet_another_function,
    # 'trigger_rule': 'all_success'
}
# [END default_args]

# [START instantiate_dag]
dag = DAG(
    'recommend-pipeline',
    default_args=default_args,
    description='Run the transient training pipeline',
    schedule_interval=timedelta(days=1),
)
# [END instantiate_dag]

t1 = BashOperator(
    task_id='docker-pipeline-run',
    bash_command='docker run recommend_pipeline',
    dag=dag,
)


# [START documentation]
dag.doc_md = __doc__

t1.doc_md = """\
#### Transient Pipeline
Downloads movielens-100k, trains a recommendation model and saves top 10 recommendations to Google BigQuery.
"""
# [END documentation]


t1
# [END tutorial]
